/*
 * ifcon_drv.h - IFCON Communication Driver
 *
 * Copyright 2017 Sony Corporation
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef DRIVERS_IFCON_DRV_IFCON_DRV_H_
#define DRIVERS_IFCON_DRV_IFCON_DRV_H_

#include <linux/types.h>

/*---- read / wrire --------------------------------------------------------*/
#define IFCON_DRV_DEVNAME "ifcon_drv"

#define USE_256FRAME (1) /* 0:128[byte],50ms[cycle] / 1:256[byte],20ms[cycle] */

#if USE_256FRAME
#define IFCON_DRV_PACKET_CTRL_AREA_SIZE	(8)
#define IFCON_DRV_FIXED_DATA_SIZE	(6)
#define IFCON_DRV_RW_DATA_SIZE		(240)
#define IFCON_DRV_CHECK_SUM_SIZE	(2)
#define IFCON_DRV_FRAME_ALL_SIZE	(256)
#else
#define IFCON_DRV_PACKET_CTRL_AREA_SIZE	(8)
#define IFCON_DRV_FIXED_DATA_SIZE	(18)
#define IFCON_DRV_RW_DATA_SIZE		(100)
#define IFCON_DRV_CHECK_SUM_SIZE	(2)
#define IFCON_DRV_FRAME_ALL_SIZE	(128)
#endif

#define IFCON_DRV_FRAME_CTRL_DEF_SIZE	(32)

struct ifcon_drv_frame_ctl_def {
	__u8	frame_size;	/* frame size */
	__u8	ctl_0;		/* ctrl data0 */
	__u8	ctl_1;		/* ctrl data1 */
	__u8	dest;		/* destination */
};

struct ifcon_drv_frame_def {
	struct ifcon_drv_frame_ctl_def	info;	/* frame ctrl info */
	__u8   data[IFCON_DRV_RW_DATA_SIZE - IFCON_DRV_FRAME_CTRL_DEF_SIZE];
};

/*---- IOCTL ---------------------------------------------------------------*/
#define IFCON_DRV_IOC_MAGIC	'i'

/* Parameter of IFCON_IOC_WRITE_FIXED / IFCON_IOC_READ_FIXED */
struct st_ifcon_fixed_data_param_def {
	__u32	offset;	/* offset from top address */
	__u32	sz;	/* data size */
	__u8	*data;	/* data pointer */
};

#define IFCON_DRV_IOC_WRITE_FIXED	_IOW(IFCON_DRV_IOC_MAGIC, 0x90, struct st_ifcon_fixed_data_param_def)
#define IFCON_DRV_IOC_READ_FIXED	_IOR(IFCON_DRV_IOC_MAGIC, 0x90, struct st_ifcon_fixed_data_param_def)

#define IFCON_DRV_OK			(0)
#define IFCON_DRV_NG			(-1)

#define IFCON_DRV_NOT_CONNECT		(0x00F2)
#define IFCON_DRV_BUFF_FULL		(0x00F3)
#define IFCON_DRV_RX_BUFF_SIZE_ERROR	(0x00F4)
#define IFCON_DRV_SUSPEND		(0x00F7)

#endif	/* DRIVERS_IFCON_DRV_IFCON_DRV_H_ */
